@@ -242,6 +242,11 @@ class FacetProperties(RABase):
         alias="virkning", description="Effective time of the property."
     )
 
+    @root_validator(pre=True)
+    def remove_integration_data(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+        values.pop("integration_data", None)
+        return values
+
 
 class FacetAttributes(RABase):
     """
@@ -341,6 +346,20 @@ class ClassRef(LoraBase):
     )
 
 
+class OwnerRef(LoraBase):
+    """
+    Reference to an organisation unit marked as owner for a LoRa class
+    """
+
+    object_type: Literal["organisationenhed"] = Field(
+        "organisationenhed", alias="objekttype", description="Object type."
+    )
+    uuid: UUID = Field(description="UUID of the reference.")
+    effective_time: EffectiveTime = Field(
+        alias="virkning", description="Effective time of the reference."
+    )
+
+
 class ParentClassification(LoraBase):
     """
     ParentClassification object in LoRa.
@@ -522,6 +541,9 @@ class KlasseProperties(RABase):
         alias="virkning", description="Effective time of the properties."
     )
     example: Optional[str] = Field(alias="eksempel", description="Example usage.")
+    description: Optional[str] = Field(
+        alias="beskrivelse", description="Description of the Klasse."
+    )
 
 
 class KlasseRelations(RABase):
@@ -544,8 +566,10 @@ class KlasseRelations(RABase):
         max_items=1,
         description="The parent class object.",
     )
-    owner: Optional[UUID] = Field(
+    owner: Optional[List[OwnerRef]] = Field(
         alias="ejer",
+        min_items=1,
+        max_items=1,
         description="Owner of class relation",
     )
 
