@@ -18,6 +18,27 @@ from ramodels.mo._shared import MOBase
 # --------------------------------------------------------------------------------------
 
 
+class FacetRead(MOBase):
+    """A MO Facet read object."""
+
+    type_: str = Field("facet", alias="type", description="The object type")
+    user_key: str = Field(description="Short, unique key.")
+    published: Optional[str] = Field(description="Published state of the facet object.")
+    org_uuid: UUID = Field(description="UUID of the related organisation.")
+    parent_uuid: Optional[UUID] = Field(description="UUID of the parent facet.")
+    description: str = Field(description="Description of the facet object.", default="")
+
+
+class FacetWrite(MOBase):
+    """A MO Facet write object."""
+
+    type_: str = Field("facet", alias="type", description="The object type")
+    user_key: str = Field(description="Short, unique key.")
+    published: Optional[str] = Field(description="Published state of the facet object.")
+    parent_uuid: Optional[UUID] = Field(description="UUID of the parent facet.")
+    description: str = Field(description="Description of the facet object.", default="")
+
+
 class FacetClass(MOBase):
     """Payload model for Klasses to be created under the given Facet."""
 
@@ -30,14 +51,3 @@ class FacetClass(MOBase):
     org_uuid: UUID = Field(
         description="UUID of the organisation for which the Klasse should be created."
     )
-
-
-class FacetRead(MOBase):
-    """A MO Facet read object."""
-
-    type_: str = Field("facet", alias="type", description="The object type")
-    user_key: str = Field(description="Short, unique key.")
-    published: Optional[str] = Field(description="Published state of the facet object.")
-    org_uuid: UUID = Field(description="UUID of the related organisation.")
-    parent_uuid: Optional[UUID] = Field(description="UUID of the parent facet.")
-    description: str = Field(description="Description of the facet object.", default="")
